@@ -1,6 +1,26 @@
-/* include file for mga_driver.c  DO NOT try to generate a .o with this file.*/
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/mga/mga_merge.c,v 1.2 2002/09/18 21:25:45 tsi Exp $ */
 
-int StrToRanges(range* r, char* s) {
+/* All drivers should typically include these */
+#include "xf86.h"
+#include "xf86_OSproc.h"
+#include "xf86Resources.h"
+
+/* All drivers need this */
+#include "xf86_ansic.h"
+
+#include "compiler.h"
+
+/* Drivers for PCI hardware need this */
+#include "xf86PciInfo.h"
+#include "mga.h"
+#include "mga_macros.h"
+#include "mga_reg.h"
+#include "mga_merge.h"
+
+#include "fbdevhw.h"
+
+static int
+StrToRanges(range* r, char* s) {
     float num=0.0;
     int rangenum=0;
     Bool gotdash = FALSE;
@@ -45,9 +65,10 @@ int StrToRanges(range* r, char* s) {
  * Links i and j in Private record.
  * if dest is NULL, return value is copy of i linked to itself.
  */
-DisplayModePtr CopyModeNLink(ScrnInfoPtr pScrn, DisplayModePtr dest, DisplayModePtr i, DisplayModePtr j, MgaScrn2Rel srel) {
+static DisplayModePtr
+CopyModeNLink(ScrnInfoPtr pScrn, DisplayModePtr dest, DisplayModePtr i, DisplayModePtr j, MgaScrn2Rel srel) {
     DisplayModePtr mode;
-    int dx,dy = 0;
+    int dx = 0,dy = 0;
     /* start with first node */
     mode = xalloc(sizeof(DisplayModeRec));
     memcpy(mode,i, sizeof(DisplayModeRec));
@@ -97,7 +118,9 @@ DisplayModePtr CopyModeNLink(ScrnInfoPtr pScrn, DisplayModePtr dest, DisplayMode
     return mode;
 }
 
-DisplayModePtr GetModeFromName(char* str, DisplayModePtr i) {
+static DisplayModePtr
+GetModeFromName(char* str, DisplayModePtr i)
+{
     DisplayModePtr c = i;
     if(!i) return NULL;
     do {
@@ -106,8 +129,11 @@ DisplayModePtr GetModeFromName(char* str, DisplayModePtr i) {
     } while(c != i);
     return NULL;
 }
+
 /* takes a config file string of MetaModes and generates a MetaModeList */
-DisplayModePtr GenerateModeList(ScrnInfoPtr pScrn, char* str, DisplayModePtr i, DisplayModePtr j, MgaScrn2Rel srel) {
+static DisplayModePtr
+GenerateModeList(ScrnInfoPtr pScrn, char* str,
+		 DisplayModePtr i, DisplayModePtr j, MgaScrn2Rel srel) {
     char* strmode = str;
     char modename[256];
     Bool gotdash = FALSE;
@@ -198,7 +224,8 @@ DisplayModePtr GenerateModeList(ScrnInfoPtr pScrn, char* str, DisplayModePtr i,
  * this function looses lots of maintainability points due to redundancy, 
  * but it still was the cleanest and least-intrusive way I found. */
 
-Bool MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
+Bool
+MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
 {
     ScrnInfoPtr pScrn;
     MGAPtr pMga;
@@ -223,7 +250,9 @@ Bool MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
     }
 
     pMga = MGAPTR(pScrn);
+#ifdef USEMGAHAL
     pMga->pMgaModeInfo = NULL; /*will be allocated later if NULL*/ 
+#endif
     pMga1 = MGAPTR(pScrn1);
     pMga1->pScrn2 = pScrn;
   
@@ -280,18 +309,19 @@ Bool MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
     
     /* Set the bits per RGB for 8bpp mode */
     if (pScrn->depth == 8)
-	pScrn->rgbBits = 8;
+    	pScrn->rgbBits = 8;
 
     /*
      * Set the Chipset and ChipRev, allowing config file entries to
      * override.
      */
-	pScrn->chipset = pScrn1->chipset;
-        pMga->Chipset = pMga1->Chipset;
-        pMga->ChipRev = pMga1->ChipRev;
+    pScrn->chipset = pScrn1->chipset;
+    pMga->Chipset = pMga1->Chipset;
+    pMga->ChipRev = pMga1->ChipRev;
 
+#ifdef XF86DRI
     pMga->agpMode = pMga1->agpMode;
-
+#endif
 
     pMga->NoAccel = pMga1->NoAccel;
     pMga->UsePCIRetry = pMga1->UsePCIRetry;
@@ -316,20 +346,20 @@ Bool MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
     pMga->Rotate = 0;
 
     switch (pMga->Chipset) {
-    case PCI_CHIP_MGA2064:
-    case PCI_CHIP_MGA2164:
-    case PCI_CHIP_MGA2164_AGP:
-	MGA2064SetupFuncs(pScrn);
-	break;
-    case PCI_CHIP_MGA1064:
-    case PCI_CHIP_MGAG100:
-    case PCI_CHIP_MGAG100_PCI:
-    case PCI_CHIP_MGAG200:
-    case PCI_CHIP_MGAG200_PCI:
-    case PCI_CHIP_MGAG400:
-    case PCI_CHIP_MGAG550:
-	MGAGSetupFuncs(pScrn);
-	break;
+        case PCI_CHIP_MGA2064:
+        case PCI_CHIP_MGA2164:
+        case PCI_CHIP_MGA2164_AGP:
+        	MGA2064SetupFuncs(pScrn);
+        	break;
+        case PCI_CHIP_MGA1064:
+        case PCI_CHIP_MGAG100:
+        case PCI_CHIP_MGAG100_PCI:
+        case PCI_CHIP_MGAG200:
+        case PCI_CHIP_MGAG200_PCI:
+        case PCI_CHIP_MGAG400:
+        case PCI_CHIP_MGAG550:
+	        MGAGSetupFuncs(pScrn);
+        	break;
     }
 
     pMga->FbAddress = pMga1->FbAddress;
@@ -376,7 +406,7 @@ Bool MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
 #if !defined(__powerpc__)
 
     /* Read and print the Monitor DDC info */
-/*    pScrn->monitor->DDC = MGAdoDDC(pScrn);*/ /*FIXME: have to try this*/
+    /*    pScrn->monitor->DDC = MGAdoDDC(pScrn);*/ /*FIXME: have to try this*/
 #endif /* !__powerpc__ */
 
     /*
@@ -384,11 +414,11 @@ Bool MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
      * here.
      */
     {
-	Gamma zeros = {0.0, 0.0, 0.0};
+    	Gamma zeros = {0.0, 0.0, 0.0};
 
-	if (!xf86SetGamma(pScrn, zeros)) {
-	    return FALSE;
-	}
+	    if (!xf86SetGamma(pScrn, zeros)) {
+	        return FALSE;
+	    }
     }
 
 
@@ -403,6 +433,7 @@ Bool MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
     } else {
         pMga->MaxClock = 135000;
     }
+
     xf86DrvMsg(pScrn->scrnIndex, X_DEFAULT, "CRTC2: Max pixel clock is %d MHz\n",
 	       pMga->MaxClock / 1000);
     /*
@@ -442,79 +473,82 @@ Bool MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
      * care of this, we don't worry about setting them here.
      */
     {
-	int Pitches1[] =
-	  {640, 768, 800, 960, 1024, 1152, 1280, 1600, 1920, 2048, 0};
-	int Pitches2[] =
-	  {512, 640, 768, 800, 832, 960, 1024, 1152, 1280, 1600, 1664,
-		1920, 2048, 0};
-	int *linePitches = NULL;
-	int minPitch = 256;
-	int maxPitch = 2048;
+    	int Pitches1[] =
+	      {640, 768, 800, 960, 1024, 1152, 1280, 1600, 1920, 2048, 0};
+    	int Pitches2[] =
+	      {512, 640, 768, 800, 832, 960, 1024, 1152, 1280, 1600, 1664,
+		    1920, 2048, 0};
+    	int *linePitches = NULL;
+	    int minPitch = 256;
+    	int maxPitch = 2048;
 
         switch(pMga->Chipset) {
-	case PCI_CHIP_MGA2064:
-	   if (!pMga->NoAccel) {
-		linePitches = xalloc(sizeof(Pitches1));
-		memcpy(linePitches, Pitches1, sizeof(Pitches1));
-		minPitch = maxPitch = 0;
-	   }
-	   break;
-	case PCI_CHIP_MGA2164:
-	case PCI_CHIP_MGA2164_AGP:
-	case PCI_CHIP_MGA1064:
-	   if (!pMga->NoAccel) {
-		linePitches = xalloc(sizeof(Pitches2));
-		memcpy(linePitches, Pitches2, sizeof(Pitches2));
-		minPitch = maxPitch = 0;
-	   }
-	   break;
-	case PCI_CHIP_MGAG100:
-	case PCI_CHIP_MGAG100_PCI:
-	   maxPitch = 2048;
-	   break;
-	case PCI_CHIP_MGAG200:
-	case PCI_CHIP_MGAG200_PCI:
-	case PCI_CHIP_MGAG400:
-	case PCI_CHIP_MGAG550:
-	   maxPitch = 4096;
-	   break;
-	}
+        	case PCI_CHIP_MGA2064:
+        	   if (!pMga->NoAccel) {
+        		linePitches = xalloc(sizeof(Pitches1));
+        		memcpy(linePitches, Pitches1, sizeof(Pitches1));
+        		minPitch = maxPitch = 0;
+        	   }
+        	   break;
+
+        	case PCI_CHIP_MGA2164:
+        	case PCI_CHIP_MGA2164_AGP:
+        	case PCI_CHIP_MGA1064:
+        	   if (!pMga->NoAccel) {
+        		linePitches = xalloc(sizeof(Pitches2));
+        		memcpy(linePitches, Pitches2, sizeof(Pitches2));
+        		minPitch = maxPitch = 0;
+        	   }
+        	   break;
+        	case PCI_CHIP_MGAG100:
+        	case PCI_CHIP_MGAG100_PCI:
+        	   maxPitch = 2048;
+        	   break;
+        	case PCI_CHIP_MGAG200:
+        	case PCI_CHIP_MGAG200_PCI:
+        	case PCI_CHIP_MGAG400:
+        	case PCI_CHIP_MGAG550:
+        	   maxPitch = 4096;
+        	   break;
+        }
 
         pScrn->modePool=NULL;
         pScrn->modes = NULL;
-	i = xf86ValidateModes(pScrn, pScrn->monitor->Modes,
+        
+	    i = xf86ValidateModes(pScrn, pScrn->monitor->Modes,
 			      pScrn->display->modes, clockRanges,
 			      linePitches, minPitch, maxPitch,
 			      pMga->Roundings[(pScrn->bitsPerPixel >> 3) - 1] *
-					pScrn->bitsPerPixel, 128, 2048,
+				  pScrn->bitsPerPixel, 128, 2048,
 			      pScrn->display->virtualX,
 			      pScrn->display->virtualY,
 			      pMga->FbMapSize,
 			      LOOKUP_BEST_REFRESH);
         
-	if (linePitches)
-	   xfree(linePitches);
+    	if (linePitches)
+	       xfree(linePitches);
     }
 
 
     if (i < 1 && pMga->FBDev) {
-	fbdevHWUseBuildinMode(pScrn);
-	pScrn->displayWidth = pScrn->virtualX; /* FIXME: might be wrong */
-	i = 1;
+    	fbdevHWUseBuildinMode(pScrn);
+	    pScrn->displayWidth = pScrn->virtualX; /* FIXME: might be wrong */
+    	i = 1;
     }
+    
     if (i == -1) {
-	xf86DrvMsg(pScrn->scrnIndex, X_ERROR, "CRTC2: Validate Modes Failed\n");
-	MGAFreeRec(pScrn);
-	return FALSE;
+	    xf86DrvMsg(pScrn->scrnIndex, X_ERROR, "CRTC2: Validate Modes Failed\n");
+    	MGAFreeRec(pScrn);
+	    return FALSE;
     }
 
     /* Prune the modes marked as invalid */
     xf86PruneDriverModes(pScrn);
 
     if (i == 0 || pScrn->modes == NULL) {
-	xf86DrvMsg(pScrn->scrnIndex, X_ERROR, "CRTC2: No valid modes found\n");
-	MGAFreeRec(pScrn);
-	return FALSE;
+    	xf86DrvMsg(pScrn->scrnIndex, X_ERROR, "CRTC2: No valid modes found\n");
+	    MGAFreeRec(pScrn);
+    	return FALSE;
     }
 #ifdef USEMGAHAL
     MGA_HAL(
@@ -522,19 +556,18 @@ Bool MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
     pMga->pBoard = pMga1->pBoard;
     pMga->pClientStruct = pMga1->pClientStruct;
     pMga->pMgaHwInfo = pMga1->pMgaHwInfo;
-
-
-    FillModeInfoStruct(pScrn,NULL);
-    /* Fields usually handled by FillModeInfoStruct, but are unavailable
+        
+    MGAFillModeInfoStruct(pScrn,NULL);
+    /* Fields usually handled by MGAFillModeInfoStruct, but are unavailable
      * because no mode is given
      */
     pMga->pMgaModeInfo->ulDispWidth = pScrn->virtualX;
     pMga->pMgaModeInfo->ulDispHeight = pScrn->virtualY;
     
     if((status = MGAValidateMode(pMga->pBoard,pMga->pMgaModeInfo)) != 0) {
-	xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
-		   "MGAValidateMode from HALlib found the mode to be invalid.\n"
-		   "\tError: 0x%lx\n", status);
+    	xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
+	    	   "MGAValidateMode from HALlib found the mode to be invalid.\n"
+		       "\tError: 0x%lx\n", status);
         return FALSE;
     }
     pScrn->displayWidth = pMga->pMgaModeInfo->ulFBPitch;
@@ -637,7 +670,7 @@ Bool MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
     return TRUE;
 }
 
-static void
+void
 MGADisplayPowerManagementSetMerged(ScrnInfoPtr pScrn, int PowerManagementMode,
 				  int flags)
 {
@@ -649,7 +682,8 @@ typedef struct _region {
     int x0,x1,y0,y1;
     } region;
 
-Bool InRegion(int x, int y, region r) {
+static Bool
+InRegion(int x, int y, region r) {
     return (r.x0 <= x) && (x < r.x1) && (r.y0 <= y) && (y < r.y1);
 }
 
@@ -794,7 +828,8 @@ MGAMergePointerMoved(int scrnIndex, int x, int y)
 }
 
    
-void MGAAdjustMergeFrames(int scrnIndex, int x, int y, int flags) {
+void
+MGAAdjustMergeFrames(int scrnIndex, int x, int y, int flags) {
     ScrnInfoPtr pScrn1 = xf86Screens[scrnIndex];
     MGAPtr pMga = MGAPTR(pScrn1); 
     ScrnInfoPtr pScrn2 = pMga->pScrn2;
@@ -864,7 +899,7 @@ void MGAAdjustMergeFrames(int scrnIndex, int x, int y, int flags) {
     return;
 }
 
-static Bool
+Bool
 MGACloseScreenMerged(int scrnIndex, ScreenPtr pScreen) {
     ScrnInfoPtr pScrn1 = xf86Screens[scrnIndex];
     MGAPtr pMga = MGAPTR(pScrn1); 
@@ -895,7 +930,7 @@ MGACloseScreenMerged(int scrnIndex, ScreenPtr pScreen) {
     return TRUE;       
 }
 
-static Bool
+Bool
 MGASaveScreenMerged(ScreenPtr pScreen, int mode)
 {
     ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
@@ -924,3 +959,5 @@ MGASaveScreenMerged(ScreenPtr pScreen, int mode)
     }
     return TRUE;
 }
+
+
